pub struct RangeAllocationError<T> {
pub fragmented_free_length: T,
}Expand description
Error type returned when a range allocation fails.
This error indicates that there is not enough contiguous space available to satisfy the allocation request, although there may be enough total free space if it were defragmented.
Fields
fragmented_free_length: TThe total length of all free ranges combined.
This value represents how much space would be available if all fragmented free ranges could be combined into one contiguous range.